<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Život existuje i mimo prohlížeč!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licence k: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je svobodný software, ale jeho vývoj stojí drahocenný čas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Prosím &lt;a href=&apos;%1&apos;&gt;přispějte&lt;/a&gt; na další vývoj %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Přeložte %1 do vašeho mateřského jazyka pomocí %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Autor ikony: %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Vydáno pod &lt;a href=&apos;%1&apos;&gt;licencí GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vložte detaily vaší licence</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Sežeňte si, prosím, licenci %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Platnost demoverze vypršela.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Plná verze umožní sledovat videa bez přerušení.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Bez licence žádost vyprší za %1 dnů</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Zakoupením plné verze také podpoříte práci, která byla vložená do tvorby %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Použít demoverzi</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vložit licenci</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Koupit licenci</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Od %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Všechna videa</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Nesledovaná videa</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Poslední aktualizace</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Naposledy přidáno</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Naposledy shlédnuto</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Nejsledovanější</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Třídit podle</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Označit jako shlédnuté</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Zobrazit aktualizace</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nemáte žádné odběry. Použijte hvězdičku k přihlásení odběru kanálů.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Všechna videa</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Nesledovaná videa</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Označit jako shlédnuté</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Nyní nejsou k dispozici žádné aktualizace odběrů.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Právě teď</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 zobrazení</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bajtů</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bajtů/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/se</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 zbývá</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 staženo v %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Stahování dokončeno</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Změnit složku pro stahování...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Vyberte složku, do které se bude stahovat</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Nastavení složky pro stahování bylo změněno.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Probíhající stahování budou stále pokračovat v ukládání do dříve nastaveného adresáře</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Stahováno do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Soubor pro spuštění byl požkozen, toto mohl zapříčinit virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 nepoběží. Zkuste instalovat znovu.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Přeinstalovat</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Pustit/Pozastavit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zastavit přehrávání po dokončení nyní přehrávaného videa</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Další video</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Předchozí video</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zvýšit hlasitost</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Snížit hlasitost</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit hlasitost</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Rychle vpřed</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Rychle vzad</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Najít videa a kanály podle klíčového slova</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Prohlížet</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Prohlížet videa podle kategorie</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Odběry</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanál odběrů</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Udělejte si pohodlí</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zastavit</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zastaví přehrávání a vrátí se zpět na vyhledávání</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;ředešlý</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Jít zpět na předchozí skladbu</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Př&amp;eskočit</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Přeskočí na další video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Pokračovat v přehrávání</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Přepne na celou obrazovku</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompaktní mód</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skryje playlist a toolbar</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Otevřít stránku &amp;YouTube </translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Otevře video na webu YouTube a pozastaví přehrávání</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopírovat YouTube &amp;odkaz</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Zkopíruje adresu videa na YouTube do schránky</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Zkopírovat adresu &amp;video streamu</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Zkopíruje do schránky adresu video streamu</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Nalézt &amp;části videa</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Najít další části videa, doufejme, že ve správném pořadí</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Odstraní vybraná videa z playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>&amp;Nahoru</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Posune vybraná videa výš v playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Dolů</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Posune vybraná videa níž v playlistu</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Vymazat poslední hledání</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Vyprázdní historii vyhledávání. Akci nelze vrátit.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Sbohem</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Homepage</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Webu</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Podpořit</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Prosím přispějte na další vývoj aplikace %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o aplikaci %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Zahájit přehrávání &amp;ručně </translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Zahájit přehrávání videí ručně</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Stahování</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Zobrazit podrobnosti o stahování videí</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Stáhnout</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Stáhnout přávě zobrazené video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Udělat &amp;Snímek</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Přihlásit se ke kanálu</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Sdílet aktuální video pomocí %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Plovoucí navrchu</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Zastavit po tomto videu</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Nahlásit chybu...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Upřesnit vyhledávání...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Více...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Související videa</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Sledovat videa související s tímto</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Otevřít v prohlížeči ...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Omezený režim</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Skrýt videa, která by mohla obsahovat nevhodný obsah</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Přepnout pruh s &amp;nabídkou</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Nabídka</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Líbí se %1? Ohodnotit!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Koupit %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikace</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Přehrávání</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Sdílet</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pohled</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Stiskněte %1 pro zvýšení hlasitosti; %2 pro snížení</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Vyberte si umístění obsahu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otevírám %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Chcete ukončit %1, přestože ještě probíhá stahování?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jestli nyní ukončíte %1, bude nedokončené stahování přerušeno</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Přerušit stahování a ukončit aplikaci</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Počkat na dokončení stahování</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pozastaví přehrávání</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Nahrávání...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opustit zobrazení na &amp;celou obrazovku</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Zbývající čas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hlasitost na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Zvuk je ztlumen</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Zvuk je zapnut</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maximální rozlišení videa je %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Vaše soukromí je nyní v bezpečí</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Všechna stahování byla dokončena</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 verze %2 je nyní dostupná.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Stále ještě můžete přistupovat k pruhu s nabídkou stisknutím klávesy Alt</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Nyní můžete vložit odkaz na video na YouTube do jiného programu</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Nyní můžete vložit odkaz na video stream do jiné aplikace</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Tento odkaz platí jen po omezenou dobu.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Je stahováno %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>z</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>část</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>epizoda</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Zaslat z %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Odhlásit z </translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Přihlásit k %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Odhlášen z odběru %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Přihlášen k odběru %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nová verze %1 je k dispozici!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 je nyní k dispozici. Vy máte %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chcete ji nyní stáhnout?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Přeskočit tuto verzi</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Nainstalovat aktualizaci</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 z %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Připravuje se</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Selhalo</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zastaveno</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Zastavit stahování</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Ukázat v %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Otevřít příslušný adresář</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Začít stahovat znovu</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Zobrazit dalších %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Žádná videa</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Žádná další videa</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Třídit podle</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Významu</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Počtu shlédnutí</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Hodnocení</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Kdykoliv</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dní</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dnů</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Krátký</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Dlouhý</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Méně než 4 minuty</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mezi 4 a 20minutami</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Delší než 20 minut</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Vysoké rozlišení</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p nebo vyšší</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Vítejte v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation> pro sledování videí.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>klíčové slovo</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Poslední klíčová slova</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Poslední kanály</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Získat plnou verzi</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Předat k %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Zpět k %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Upřesnit vyhledávání</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Měli jste na mysli: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Změnit složku pro stahování...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Snímek uložen do %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Umístění snímku se změnilo.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Nejoblíbenější</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Stahování aktualizace...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Stahování %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Alžírsko</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Austrálie</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgie</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazílie</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbie</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Česká republika</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francie</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Německo</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Řecko</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Maďarsko</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indie</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesie</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irsko</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Itálie</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonsko</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordánsko</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Keňa</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malajsie</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nizozemí</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nový Zéland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Niger</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipíny</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polsko</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusko</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudská Arabie</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Jižní Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Severní Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Španělsko</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Švédsko</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisko</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turecko</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Spojené arabské emiráty</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Velká Británie</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Celosvětově</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nelze získat video stream pro %1</translation>
    </message>
</context>
</TS>